==> ooo_dev_tools-0.17.2-py3-none-any.whl: ooodev/format/writer/modify/para/area/__init__.py <==
import uno
from ooo.dyn.drawing.rectangle_point import RectanglePoint as RectanglePoint
from ooo.dyn.drawing.hatch_style import HatchStyle as HatchStyle

from ooodev.format.inner.direct.write.fill.area.img import ImgStyleKind as ImgStyleKind
from ooodev.format.inner.direct.write.fill.area.img import OffsetColumn as OffsetColumn
from ooodev.format.inner.direct.write.fill.area.img import OffsetRow as OffsetRow
from ooodev.format.inner.direct.write.fill.area.img import SizePercent as SizePercent
from ooodev.format.inner.modify.write.para.area.color import Color as Color
from ooodev.format.inner.modify.write.para.area.gradient import Gradient as Gradient
from ooodev.format.inner.modify.write.para.area.hatch import Hatch as Hatch
from ooodev.format.inner.modify.write.para.area.hatch import InnerHatch as InnerHatch
from ooodev.format.inner.modify.write.para.area.img import Img as Img
from ooodev.format.inner.modify.write.para.area.img import InnerImg as InnerImg
from ooodev.format.inner.modify.write.para.area.pattern import InnerPattern as InnerPattern
from ooodev.format.inner.modify.write.para.area.pattern import Pattern as Pattern
from ooodev.format.inner.preset.preset_gradient import PresetGradientKind as PresetGradientKind
from ooodev.format.inner.preset.preset_hatch import PresetHatchKind as PresetHatchKind
from ooodev.format.inner.preset.preset_image import PresetImageKind as PresetImageKind
from ooodev.format.inner.preset.preset_pattern import PresetPatternKind as PresetPatternKind
from ooodev.format.writer.style.para.kind import StyleParaKind as StyleParaKind
from ooodev.utils.data_type.angle import Angle as Angle
from ooodev.utils.data_type.color_range import ColorRange as ColorRange
from ooodev.utils.data_type.intensity import Intensity as Intensity
from ooodev.utils.data_type.intensity_range import IntensityRange as IntensityRange
from ooodev.utils.data_type.offset import Offset as Offset
from ooodev.utils.data_type.size_mm import SizeMM as SizeMM

__all__ = ["Color", "Gradient", "Hatch", "Img", "Pattern"]

==> ooo_dev_tools-0.25.1-py3-none-any.whl: ooodev/format/writer/modify/para/area/__init__.py <==
import uno
from ooo.dyn.drawing.rectangle_point import RectanglePoint as RectanglePoint
from ooo.dyn.drawing.hatch_style import HatchStyle as HatchStyle

from ooodev.format.inner.direct.write.fill.area.img import ImgStyleKind as ImgStyleKind
from ooodev.format.inner.direct.write.fill.area.img import OffsetColumn as OffsetColumn
from ooodev.format.inner.direct.write.fill.area.img import OffsetRow as OffsetRow
from ooodev.format.inner.direct.write.fill.area.img import SizePercent as SizePercent
from ooodev.format.inner.modify.write.para.area.color import Color as Color
from ooodev.format.inner.modify.write.para.area.gradient import Gradient as Gradient
from ooodev.format.inner.modify.write.para.area.hatch import Hatch as Hatch
from ooodev.format.inner.modify.write.para.area.hatch import InnerHatch as InnerHatch
from ooodev.format.inner.modify.write.para.area.img import Img as Img
from ooodev.format.inner.modify.write.para.area.img import InnerImg as InnerImg
from ooodev.format.inner.modify.write.para.area.pattern import InnerPattern as InnerPattern
from ooodev.format.inner.modify.write.para.area.pattern import Pattern as Pattern
from ooodev.format.inner.preset.preset_gradient import PresetGradientKind as PresetGradientKind
from ooodev.format.inner.preset.preset_hatch import PresetHatchKind as PresetHatchKind
from ooodev.format.inner.preset.preset_image import PresetImageKind as PresetImageKind
from ooodev.format.inner.preset.preset_pattern import PresetPatternKind as PresetPatternKind
from ooodev.format.writer.style.para.kind import StyleParaKind as StyleParaKind
from ooodev.units import Angle as Angle
from ooodev.utils.data_type.color_range import ColorRange as ColorRange
from ooodev.utils.data_type.intensity import Intensity as Intensity
from ooodev.utils.data_type.intensity_range import IntensityRange as IntensityRange
from ooodev.utils.data_type.offset import Offset as Offset
from ooodev.utils.data_type.size_mm import SizeMM as SizeMM

__all__ = ["Color", "Gradient", "Hatch", "Img", "Pattern"]
